@@ -28,37 +28,27 @@ sub descend
 
 	my $h2 = $self->{val};
 
-	return 0 unless Test::Deep::hashkeys(keys %$h2)->descend($h1);
+	return 0 unless Test::Deep::descend($h1, Test::Deep::hashkeys(keys %$h2));
 
 	return 0 unless $self->test_class($h1);
 
-
-	my $ok = 1;
-
-	my %data = (type => $self);
-
-	$Test::Deep::Stack->push(\%data);
+	my $data = $self->push;
 
 	my $bigger = keys %$h1 > keys %$h2 ? $h1 : $h2;
 
 	foreach my $key (keys %$bigger)
 	{
-		$data{index} = $key;
+		$data->{index} = $key;
 
 		my $got = exists $h1->{$key} ? $h1->{$key} : $Test::Deep::DNE;
 		my $expected = exists $h2->{$key} ? $h2->{$key} : $Test::Deep::DNE;
 
-		$ok = Test::Deep::descend($got, $expected);
+		next if Test::Deep::descend($got, $expected);
 
-		if (! $ok)
-		{
-			$data{vals} = [$got, $expected];
-			last;
-		}
+		return 0;
 	}
 
-	$Test::Deep::Stack->pop if $ok;
-	return $ok;
+	return 1;
 }
 
 sub render_stack
