@@ -15,9 +15,9 @@ sub init
 {
 	my $self = shift;
 
-	my $dupes = shift;
+	$self->{IgnoreDupes} = shift;
+	$self->{SubSup} = shift;
 
-	$self->{IgnoreDupes} = $dupes;
 	$self->{val} = [];
 
 	$self->add(@_);
@@ -31,12 +31,11 @@ sub descend
 	my $d2 = $self->{val};
 
 	my $IgnoreDupes = $self->{IgnoreDupes};
+	my $SubSup = $self->{SubSup};
 
 	my $type = $IgnoreDupes ? "Set" : "Bag";
 
-	my %data = (type => $self);
-
-	$Test::Deep::Stack->push(\%data);
+	my $data = $self->push;
 
 	my $diag;
 
@@ -71,37 +70,32 @@ EOM
 			push(@missing, $expect) unless $found;
 		}
 
-		my $got = __PACKAGE__->new($IgnoreDupes, @got);
 
 		my @diags;
-		if (@missing)
+		if (@missing and $SubSup ne "sub")
 		{
 			push(@diags, "Missing: ".nice_list(\@missing));
 		}
 
-		if (@got)
+		if (@got and $SubSup ne "sup")
 		{
+			my $got = __PACKAGE__->new($IgnoreDupes, "", @got);
 			push(@diags, "Extra: ".nice_list($got->{val}));
 		}
 
 		$diag = join("\n", @diags);
 	}
 
-	my $ok;
 	if ($diag)
 	{
-		$ok = 0;
+		$data->{diag} = $diag;
 
-		$data{diag} = $diag;
+		return 0;
 	}
 	else
 	{
-		$ok = 1;
+		return 1;
 	}
-
-	$Test::Deep::Stack->pop if $ok;
-
-	return $ok;
 }
 
 sub diagnostics
@@ -110,6 +104,8 @@ sub diagnostics
 	my ($where, $last) = @_;
 
 	my $type = $self->{IgnoreDupes} ? "Set" : "Bag";
+	$type = "Sub$type" if $self->{SubSup} eq "sub";
+	$type = "Super$type" if $self->{SubSup} eq "sup";
 
 	my $error = $last->{diag};
 	my $diag = <<EOM;
